% Auto-generated chapter 17 for tirmidhi
% Hadiths in this chapter: 45

\hadithdefcmd{tirmidhi}{1423}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الْقُطَعِيُّ الْبَصْرِيُّ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ الْبَصْرِيِّ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ رُفِعَ الْقَلَمُ عَنْ ثَلاَثَةٍ عَنِ النَّائِمِ حَتَّى يَسْتَيْقِظَ وَعَنِ الصَّبِيِّ حَتَّى يَشِبَّ وَعَنِ الْمَعْتُوهِ حَتَّى يَعْقِلَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَذَكَرَ بَعْضُهُمْ ‏"‏ وَعَنِ الْغُلاَمِ حَتَّى يَحْتَلِمَ ‏"‏ ‏.‏ وَلاَ نَعْرِفُ لِلْحَسَنِ سَمَاعًا عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَطَاءِ بْنِ السَّائِبِ عَنْ أَبِي ظَبْيَانَ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا الْحَدِيثِ ‏.‏ وَرَوَاهُ الأَعْمَشُ عَنْ أَبِي ظَبْيَانَ عَنِ ابْنِ عَبَّاسٍ عَنْ عَلِيٍّ مَوْقُوفًا وَلَمْ يَرْفَعْهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ قَالَ أَبُو عِيسَى قَدْ كَانَ الْحَسَنُ فِي زَمَانِ عَلِيٍّ وَقَدْ أَدْرَكَهُ وَلَكِنَّا لاَ نَعْرِفُ لَهُ سَمَاعًا مِنْهُ وَأَبُو ظَبْيَانَ اسْمُهُ حُصَيْنُ بْنُ جُنْدَبٍ ‏.‏\hadithno{1423}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Ali:That the Messenger of Allah (ﷺ) said: "The pen has been lifted from three; for the sleeping person until he awakens, for the boy until he becomes a young man and for the mentally insane until he regains sanity}}
\hadithdefcmd{tirmidhi}{1424}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ أَبُو عَمْرٍو الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، حَدَّثَنَا يَزِيدُ بْنُ زِيَادٍ الدِّمَشْقِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ادْرَءُوا الْحُدُودَ عَنِ الْمُسْلِمِينَ مَا اسْتَطَعْتُمْ فَإِنْ كَانَ لَهُ مَخْرَجٌ فَخَلُّوا سَبِيلَهُ فَإِنَّ الإِمَامَ أَنْ يُخْطِئَ فِي الْعَفْوِ خَيْرٌ مِنْ أَنْ يُخْطِئَ فِي الْعُقُوبَةِ ‏"‏ ‏\hadithno{1424}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif}\hadithtrans{Narrated 'Aishah: that the Messenger of Allah (ﷺ): "Avert the legal penalties from the Muslims as much as possible, if he has a way out then leave him to his way, for if the Imam makes a mistake in forgiving it would be better than making mistake in punishment}}
\hadithdefcmd{tirmidhi}{1424p2}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ يَزِيدَ بْنِ زِيَادٍ، نَحْوَ حَدِيثِ مُحَمَّدِ بْنِ رَبِيعَةَ وَلَمْ يَرْفَعْهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ، وَعَبْدِ اللَّهِ بْنِ عَمْرٍو، ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ رَبِيعَةَ عَنْ يَزِيدَ بْنِ زِيَادٍ الدِّمَشْقِيِّ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ وَكِيعٌ عَنْ يَزِيدَ بْنِ زِيَادٍ نَحْوَهُ وَلَمْ يَرْفَعْهُ وَرِوَايَةُ وَكِيعٍ أَصَحُّ ‏.‏ وَقَدْ رُوِيَ نَحْوُ هَذَا عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمْ قَالُوا مِثْلَ ذَلِكَ ‏.‏ وَيَزِيدُ بْنُ زِيَادٍ الدِّمَشْقِيُّ ضَعِيفٌ فِي الْحَدِيثِ وَيَزِيدُ بْنُ أَبِي زِيَادٍ الْكُوفِيُّ أَثْبَتُ مِنْ هَذَا وَأَقْدَمُ ‏.‏\hadithno{1424.2}\hadithtrans{(Another chain) which is similar to the narration of Muhammad bin Rabi'ah (a narrator in no.1424) but he did not narrate it in Marfu' form}}
\hadithdefcmd{tirmidhi}{1425}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَفَّسَ عَنْ مُؤْمِنٍ كُرْبَةً مِنْ كُرَبِ الدُّنْيَا نَفَّسَ اللَّهُ عَنْهُ كُرْبَةً مِنْ كُرَبِ الآخِرَةِ وَمَنْ سَتَرَ عَلَى مُسْلِمٍ سَتَرَهُ اللَّهُ فِي الدُّنْيَا وَالآخِرَةِ وَاللَّهُ فِي عَوْنِ الْعَبْدِ مَا كَانَ الْعَبْدُ فِي عَوْنِ أَخِيهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُقْبَةَ بْنِ عَامِرٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ هَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ رِوَايَةِ أَبِي عَوَانَةَ ‏.‏\hadithno{1425}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Whoever relieves a Muslim of a burden from the burdens of the world, Allah will relieve him of a burden from the burdens of the Hereafter. And whoever covers (the faults of) a Muslim, Allah will cover (his faults) for him in the world and the Hereafter. And Allah is engaged in helping the worshipper as long as the worshipper is engaged in helping his brother}}
\hadithdefcmd{tirmidhi}{1425p2}{وَرَوَى أَسْبَاطُ بْنُ مُحَمَّدٍ، عَنِ الأَعْمَشِ، قَالَ حُدِّثْتُ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَكَأَنَّ هَذَا أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ حَدَّثَنَا بِذَلِكَ عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ قَالَ حَدَّثَنِي أَبِي عَنِ الأَعْمَشِ بِهَذَا الْحَدِيثِ ‏.‏\hadithno{1425.2}\hadithtrans{Asbat bin Muhammad reported it from Al-A'mash who said: "It has been narrated to me from Abu Salih, from Abu Hurairah, from the Prophet (ﷺ)," and it is similar. [It is as if this is more correct than the first narration.] (Another chain) for this Hadith}}
\hadithdefcmd{tirmidhi}{1426}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْلِمُ أَخُو الْمُسْلِمِ لاَ يَظْلِمُهُ وَلاَ يُسْلِمُهُ وَمَنْ كَانَ فِي حَاجَةِ أَخِيهِ كَانَ اللَّهُ فِي حَاجَتِهِ وَمَنْ فَرَّجَ عَنْ مُسْلِمٍ كُرْبَةً فَرَّجَ اللَّهُ عَنْهُ كُرْبَةً مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ وَمَنْ سَتَرَ مُسْلِمًا سَتَرَهُ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عُمَرَ.‏\hadithno{1426}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Ibn 'Umar:That the Messenger of Allah (ﷺ) said: "The Muslim is the brother of the Muslim, he doesn't oppress him and doesn't put him into ruin, and whoever is concerned for the needs of his brother, Allah is concerned for his needs, and whoever relieves a Muslim of a burden, Allah will relieve him of a burden from the burdens of the Day of Judgement and whoever covers (the faults of) a Muslim, Allah will cover (his faults) on the Day of Judgement}}
\hadithdefcmd{tirmidhi}{1427}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِمَاعِزِ بْنِ مَالِكٍ ‏"‏ أَحَقٌّ مَا بَلَغَنِي عَنْكَ ‏"‏ ‏.‏ قَالَ وَمَا بَلَغَكَ عَنِّي قَالَ ‏"‏ بَلَغَنِي أَنَّكَ وَقَعْتَ عَلَى جَارِيَةِ آلِ فُلاَنٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَشَهِدَ أَرْبَعَ شَهَادَاتٍ فَأَمَرَ بِهِ فَرُجِمَ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ السَّائِبِ بْنِ يَزِيدَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ سِمَاكِ بْنِ حَرْبٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ مُرْسَلاً وَلَمْ يَذْكُرْ فِيهِ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{1427}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Abbas:That the Prophet (ﷺ) said to Ma'iz bin Malik: "Is what has reached me about you true?" He said: "What has reached you about me?" He said: "It has reached me that you had relations with the slave-maid of the family of so-and-so" He said: "Yes." So he testified four times, and he gave the order that he be stoned}}
\hadithdefcmd{tirmidhi}{1428}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ مَاعِزٌ الأَسْلَمِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّهُ قَدْ زَنَى ‏.‏ فَأَعْرَضَ عَنْهُ ثُمَّ جَاءَ مِنْ شِقِّهِ الآخَرِ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهُ قَدْ زَنَى ‏.‏ فَأَعْرَضَ عَنْهُ ثُمَّ جَاءَ مِنْ شِقِّهِ الآخَرِ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهُ قَدْ زَنَى ‏.‏ فَأَمَرَ بِهِ فِي الرَّابِعَةِ فَأُخْرِجَ إِلَى الْحَرَّةِ فَرُجِمَ بِالْحِجَارَةِ فَلَمَّا وَجَدَ مَسَّ الْحِجَارَةِ فَرَّ يَشْتَدُّ حَتَّى مَرَّ بِرَجُلٍ مَعَهُ لَحْىُ جَمَلٍ فَضَرَبَهُ بِهِ وَضَرَبَهُ النَّاسُ حَتَّى مَاتَ فَذَكَرُوا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ فَرَّ حِينَ وَجَدَ مَسَّ الْحِجَارَةِ وَمَسَّ الْمَوْتِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَلاَّ تَرَكْتُمُوهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَرُوِيَ هَذَا الْحَدِيثُ عَنِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏\hadithno{1428}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:"Ma'iz Al-Aslamu came to the Messenger of Allah (ﷺ) and said that he had committed adultery, so he (ﷺ) turned away from him. Then he approached from his other side and said: '[O Messenger of Allah!] I have committed adultery.' So he turned away from him. The he came from his other side and said: 'O Messenger of Allah! I have committed adultery.' So he gave the order (for stoning) upon the fourth time. He was taken to Al-Harrah and stoned with rocks, he ran swiftly until he passed a man with a camel whip who beat him with it, and the people beat him until he died. They mentioned to the Messenger of Allah (ﷺ), that he ran upon feeling the rocks at the time of death. So the Messenger of Allah (ﷺ) said: 'Why didn't you leave him?}}
\hadithdefcmd{tirmidhi}{1429}{حَدَّثَنَا بِذَلِكَ الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مِنْ أَسْلَمَ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَاعْتَرَفَ بِالزِّنَا فَأَعْرَضَ عَنْهُ ثُمَّ اعْتَرَفَ فَأَعْرَضَ عَنْهُ حَتَّى شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبِكَ جُنُونٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَحْصَنْتَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ فَأَمَرَ بِهِ فَرُجِمَ بِالْمُصَلَّى فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ فَرَّ فَأُدْرِكَ فَرُجِمَ حَتَّى مَاتَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْرًا وَلَمْ يُصَلِّ عَلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ أَنَّ الْمُعْتَرِفَ بِالزِّنَا إِذَا أَقَرَّ عَلَى نَفْسِهِ أَرْبَعَ مَرَّاتٍ أُقِيمَ عَلَيْهِ الْحَدُّ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا أَقَرَّ عَلَى نَفْسِهِ مَرَّةً أُقِيمَ عَلَيْهِ الْحَدُّ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ ‏.‏ وَحُجَّةُ مَنْ قَالَ هَذَا الْقَوْلَ حَدِيثُ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا يَا رَسُولَ اللَّهِ إِنَّ ابْنِي زَنَى بِامْرَأَةِ هَذَا الْحَدِيثَ بِطُولِهِ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اغْدُ يَا أُنَيْسُ عَلَى امْرَأَةِ هَذَا فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏ ‏.‏ وَلَمْ يَقُلْ فَإِنِ اعْتَرَفَتْ أَرْبَعَ مَرَّاتٍ ‏.‏\hadithno{1429}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir bin 'Abdullah:"A man from the tribe of Aslam came to the Prophet (ﷺ) and confessed adultery. He turned away from him, the he confessed (again). Then he turned away from him (again) until he had testified against himself four times. So the Prophet (ﷺ) said: "Are you insane?" He said:"No" He said: "Are you married?" He said: "Yes". So he gave the order and he was stoned at the Musalla. He ran when he was stuck by the stones, and he was caught and stoned until he died. So the Messenger of Allah (ﷺ) spoke well of him but he did not perform the (funeral) Salat for him}}
\hadithdefcmd{tirmidhi}{1430}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ قُرَيْشًا، أَهَمَّهُمْ شَأْنُ الْمَرْأَةِ الْمَخْزُومِيَّةِ الَّتِي سَرَقَتْ فَقَالُوا مَنْ يُكَلِّمُ فِيهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالُوا مَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ بْنُ زَيْدٍ حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَكَلَّمَهُ أُسَامَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ ثُمَّ قَامَ فَاخْتَطَبَ فَقَالَ ‏"‏ إِنَّمَا أَهْلَكَ الَّذِينَ مِنْ قَبْلِكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ وَايْمُ اللَّهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ مَسْعُودِ ابْنِ الْعَجْمَاءِ وَيُقَالُ مَسْعُودُ بْنُ الأَعْجَمِ وَابْنِ عُمَرَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1430}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:"The Quraish were troubled by the affair of a woman from the tribe of Makhzum who stole. So they said: 'Who will speak about her to the Messenger of Allah (ﷺ)?' They said: 'Who can do it other than Usamah bin Zaid, the one dear to the Messenger of Allah?' So Usamah spoke with him, the Messenger of Allah (ﷺ) said: 'Do you intercede about a penalty from Allah's penalties?' Then he stood up and adressed the people saying: 'Those before you were only destroyed because they used to leave a noble person if he stole. And if a weak person stole they would establish the penalty upon him. And by Allah! If Fatimah bint Muhammad stole, then I would cut off her hand}}
\hadithdefcmd{tirmidhi}{1431}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ رَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَمَ أَبُو بَكْرٍ وَرَجَمْتُ وَلَوْلاَ أَنِّي أَكْرَهُ أَنْ أَزِيدَ فِي كِتَابِ اللَّهِ لَكَتَبْتُهُ فِي الْمُصْحَفِ فَإِنِّي قَدْ خَشِيتُ أَنْ تَجِيءَ أَقْوَامٌ فَلاَ يَجِدُونَهُ فِي كِتَابِ اللَّهِ فَيَكْفُرُونَ بِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَرُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عُمَرَ ‏.‏\hadithno{1431}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umar bin Al-Khattab said:"The Messenger of Allah (ﷺ) stoned, Abu Bakr stoned, and I stoned. If I didn't dislike that I add to the Book of Allah. I would have written it in the Mushaf, for I fear that there will come a people and they will not find it in the Book of Allah, so they will disbelieve in it}}
\hadithdefcmd{tirmidhi}{1432}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ إِنَّ اللَّهَ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ وَأَنْزَلَ عَلَيْهِ الْكِتَابَ فَكَانَ فِيمَا أَنْزَلَ عَلَيْهِ آيَةُ الرَّجْمِ فَرَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَمْنَا بَعْدَهُ وَإِنِّي خَائِفٌ أَنْ يَطُولَ بِالنَّاسِ زَمَانٌ فَيَقُولَ قَائِلٌ لاَ نَجِدُ الرَّجْمَ فِي كِتَابِ اللَّهِ فَيَضِلُّوا بِتَرْكِ فَرِيضَةٍ أَنْزَلَهَا اللَّهُ أَلاَ وَإِنَّ الرَّجْمَ حَقٌّ عَلَى مَنْ زَنَى إِذَا أَحْصَنَ وَقَامَتِ الْبَيِّنَةُ أَوْ كَانَ حَبَلٌ أَوِ اعْتِرَافٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَرُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عُمَرَ رَضِيَ اللَّهُ عَنْهُ.‏\hadithno{1432}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umar bin Al-Khattab said:"Verily Allah sent Muhammad (ﷺ) with the truth, and he revealed the Book to him. Among what was revealed to him was the Ayah of stoning. So the Messenger of Allah (ﷺ) stoned, and we stoned after him. I fear that time will pass over the people such that someone will say 'We do not see stoning in the Book of Allah.' They will be misguided by leaving an obligation which Allah revealed. Indeed stoning is the retribution for the adulterer if he was married and the evidence has been established, or due to pregnancy, or confession}}
\hadithdefcmd{tirmidhi}{1433}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَغَيْرُ، وَاحِدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، سَمِعَهُ مِنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، وَشِبْلٍ، أَنَّهُمْ كَانُوا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأَتَاهُ رَجُلاَنِ يَخْتَصِمَانِ فَقَامَ إِلَيْهِ أَحَدُهُمَا وَقَالَ أَنْشُدُكَ اللَّهَ يَا رَسُولَ اللَّهِ لَمَّا قَضَيْتَ بَيْنَنَا بِكِتَابِ اللَّهِ ‏.‏ فَقَالَ خَصْمُهُ وَكَانَ أَفْقَهَ مِنْهُ أَجَلْ يَا رَسُولَ اللَّهِ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ وَائْذَنْ لِي فَأَتَكَلَّمَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا فَزَنَا بِامْرَأَتِهِ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ فَفَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَخَادِمٍ ثُمَّ لَقِيتُ نَاسًا مِنْ أَهْلِ الْعِلْمِ فَزَعَمُوا أَنَّ عَلَى ابْنِي جَلْدَ مِائَةٍ وَتَغْرِيبَ عَامٍ وَإِنَّمَا الرَّجْمُ عَلَى امْرَأَةِ هَذَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ الْمِائَةُ شَاةٍ وَالْخَادِمُ رَدٌّ عَلَيْكَ وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ وَاغْدُ يَا أُنَيْسُ عَلَى امْرَأَةِ هَذَا فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏ ‏.‏ فَغَدَا عَلَيْهَا فَاعْتَرَفَتْ فَرَجَمَهَا ‏.‏\hadithno{1433}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{Narrated 'Ubaidullah bin 'Abdullah bin 'Uthbah:That he heard from Abu Hurairah, Zaid bin Khalid, and Shibl, that they were with the Prophet (ﷺ) and two men came to him disputing. So one of them stood before him and said: "I ask you by Allah, O Messenger of Allah! Only that you would judge between us by the book of Allah." So his disputant said - and he was more eloquent that him: "I agree of O Messenger of Allah! Judge between us by the Book of Allah, and allow me to speak. My son was a servant for this man and he committed adultery with his wife. So they told me that my son was to be stoned. I paid him one hundred female sheep and a female slave. Then I met some people from the people of knowledge and they said that my son was to be lashed one hundred times, and to be banished for a year and that stoning is only for this man's wife." So the Prophet (ﷺ) said: "By the One in Whose Hand is my soul! I will judge between you two by the Book of Allah. The one hundred female sheep and the female slave should be returned to you. For your son is one hundred lashes and banishment for a year. O Unais! Go to this Man's wife, and if she confesses then stone her." He went to her and she confessed, so he stoned her}}
\hadithdefcmd{tirmidhi}{1433p2}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏\hadithno{1433.2}\hadithtrans{(Another chain) with similar}}
\hadithdefcmd{tirmidhi}{1433p3}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِهِ نَحْوَ حَدِيثِ مَالِكٍ بِمَعْنَاهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَكْرَةَ وَعُبَادَةَ بْنِ الصَّامِتِ وَأَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ وَابْنِ عَبَّاسٍ وَجَابِرِ بْنِ سَمُرَةَ وَهَزَّالٍ وَبُرَيْدَةَ وَسَلَمَةَ بْنِ الْمُحَبِّقِ وَأَبِي بَرْزَةَ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى مَالِكُ بْنُ أَنَسٍ وَمَعْمَرٌ وَغَيْرُ وَاحِدٍ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ عَنْ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَوْا بِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِذَا زَنَتِ الأَمَةُ فَاجْلِدُوهَا فَإِنْ زَنَتْ فِي الرَّابِعَةِ فَبِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏ ‏.‏ وَرَوَى سُفْيَانُ بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ عَنْ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ وَشِبْلٍ قَالُوا كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ هَكَذَا رَوَى ابْنُ عُيَيْنَةَ الْحَدِيثَيْنِ جَمِيعًا عَنْ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ وَشِبْلٍ وَحَدِيثُ ابْنِ عُيَيْنَةَ وَهَمٌ وَهِمَ فِيهِ سُفْيَانُ بْنُ عُيَيْنَةَ أَدْخَلَ حَدِيثًا فِي حَدِيثٍ ‏.‏ وَالصَّحِيحُ مَا رَوَى مُحَمَّدُ بْنُ الْوَلِيدِ الزُّبَيْدِيُّ وَيُونُسُ بْنُ يَزِيدَ وَابْنُ أَخِي الزُّهْرِيِّ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ عَنْ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا زَنَتِ الأَمَةُ فَاجْلِدُوهَا ‏"‏ ‏.‏ وَالزُّهْرِيُّ عَنْ عُبَيْدِ اللَّهِ عَنْ شِبْلِ بْنِ خَالِدٍ عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ الأَوْسِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا زَنَتِ الأَمَةُ ‏"‏ ‏.‏ وَهَذَا الصَّحِيحُ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ - وَشِبْلُ بْنُ خَالِدٍ لَمْ يُدْرِكِ النَّبِيَّ صلى الله عليه وسلم إِنَّمَا رَوَى شِبْلٌ عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ الأَوْسِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهَذَا الصَّحِيحُ وَحَدِيثُ ابْنِ عُيَيْنَةَ غَيْرُ مَحْفُوظٍ وَرُوِيَ عَنْهُ أَنَّهُ قَالَ شِبْلُ بْنُ حَامِدٍ وَهُوَ خَطَأٌ إِنَّمَا هُوَ شِبْلُ بْنُ خَالِدٍ وَيُقَالُ أَيْضًا شِبْلُ بْنُ خُلَيْدٍ ‏.‏\hadithno{1433.3}\hadithtrans{(Another chain) with similar}}
\hadithdefcmd{tirmidhi}{1434}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا هُشَيْمٌ، عَنْ مَنْصُورِ بْنِ زَاذَانَ، عَنِ الْحَسَنِ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذُوا عَنِّي فَقَدْ جَعَلَ اللَّهُ لَهُنَّ سَبِيلاً الثَّيِّبُ بِالثَّيِّبِ جَلْدُ مِائَةٍ ثُمَّ الرَّجْمُ وَالْبِكْرُ بِالْبِكْرِ جَلْدُ مِائَةٍ وَنَفْىُ سَنَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عَلِيُّ بْنُ أَبِي طَالِبٍ وَأُبَىُّ بْنُ كَعْبٍ وَعَبْدُ اللَّهِ بْنُ مَسْعُودٍ وَغَيْرُهُمْ قَالُوا الثَّيِّبُ تُجْلَدُ وَتُرْجَمُ ‏.‏ وَإِلَى هَذَا ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ إِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ وَعُمَرُ وَغَيْرُهُمَا الثَّيِّبُ إِنَّمَا عَلَيْهِ الرَّجْمُ وَلاَ يُجْلَدُ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلُ هَذَا فِي غَيْرِ حَدِيثٍ فِي قِصَّةِ مَاعِزٍ وَغَيْرِهِ أَنَّهُ أَمَرَ بِالرَّجْمِ وَلَمْ يَأْمُرْ أَنْ يُجْلَدَ قَبْلَ أَنْ يُرْجَمَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ ‏.‏\hadithno{1434}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Ubadah bin As-Samit:"The Messenger of Allah (ﷺ) said: 'Take from me. For Allah has a way made for them : For the married person who commits adultery with a married person is one hundred lashes, then stoning. And for the virgin who commits adultery with a virgin is one hundred lashes and banishment for a year}}
\hadithdefcmd{tirmidhi}{1435}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ امْرَأَةً، مِنْ جُهَيْنَةَ اعْتَرَفَتْ عِنْدَ النَّبِيِّ صلى الله عليه وسلم بِالزِّنَا فَقَالَتْ إِنِّي حُبْلَى ‏.‏ فَدَعَا النَّبِيُّ صلى الله عليه وسلم وَلِيَّهَا فَقَالَ ‏"‏ أَحْسِنْ إِلَيْهَا فَإِذَا وَضَعَتْ حَمْلَهَا فَأَخْبِرْنِي ‏"‏ ‏.‏ فَفَعَلَ فَأَمَرَ بِهَا فَشُدَّتْ عَلَيْهَا ثِيَابُهَا ثُمَّ أَمَرَ بِرَجْمِهَا فَرُجِمَتْ ثُمَّ صَلَّى عَلَيْهَا فَقَالَ لَهُ عُمَرُ بْنُ الْخَطَّابِ يَا رَسُولَ اللَّهِ رَجَمْتَهَا ثُمَّ تُصَلِّي عَلَيْهَا ‏.‏ فَقَالَ ‏"‏ لَقَدْ تَابَتْ تَوْبَةً لَوْ قُسِمَتْ بَيْنَ سَبْعِينَ مِنْ أَهْلِ الْمَدِينَةِ لَوَسِعَتْهُمْ وَهَلْ وَجَدْتَ شَيْئًا أَفْضَلَ مِنْ أَنْ جَادَتْ بِنَفْسِهَا لِلَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1435}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Imran bin Husain:"A woman from Juhainah confessed before the Prophet (ﷺ) that she had committed adultery, and she said: 'I am pregnant.' So the Prophet (ﷺ) called for her guardian and said: 'Be good to her and if she gives birth to her child then tell me.' So he did so, and then he (ﷺ) gave the order that her clothes be bound tightly around her. Then he ordered her to be stoned and she was stoned. Then he performed (funeral) Salat for her. So 'Umar bin Al-Khattab said to him: 'O Messenger of Allah! You stoned her then you prayed for her?!' He said: 'She has repented a repentance that, if distributed among seventy of the people of Al-Madinah, it would have sufficed them. Have you ever seen something more virtuous than her sacrificing herself for the sake of Allah?}}
\hadithdefcmd{tirmidhi}{1436}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَجَمَ يَهُودِيًّا وَيَهُودِيَّةً ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْحَدِيثِ قِصَّةٌ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1436}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:That the Messenger of Allah (ﷺ) stoned a Jew and Jewess}}
\hadithdefcmd{tirmidhi}{1437}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا شَرِيكٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَجَمَ يَهُودِيًّا وَيَهُودِيَّةً ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَالْبَرَاءِ وَجَابِرٍ وَابْنِ أَبِي أَوْفَى وَعَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ جَزْءٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرِ بْنِ سَمُرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ قَالُوا إِذَا اخْتَصَمَ أَهْلُ الْكِتَابِ وَتَرَافَعُوا إِلَى حُكَّامِ الْمُسْلِمِينَ حَكَمُوا بَيْنَهُمْ بِالْكِتَابِ وَالسُّنَّةِ وَبِأَحْكَامِ الْمُسْلِمِينَ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ يُقَامُ عَلَيْهِمُ الْحَدُّ فِي الزِّنَا ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1437}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir bin Samurah:That the Prophet (ﷺ) stoned a Jew and a Jewess}}
\hadithdefcmd{tirmidhi}{1438}{\hadithno{1438}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1439}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فِي مَجْلِسٍ فَقَالَ ‏ "‏ تُبَايِعُونِي عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَسْرِقُوا وَلاَ تَزْنُوا قَرَأَ عَلَيْهِمُ الآيَةَ فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَعُوقِبَ عَلَيْهِ فَهُوَ كَفَّارَةٌ لَهُ وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَسَتَرَهُ اللَّهُ عَلَيْهِ فَهُوَ إِلَى اللَّهِ إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ غَفَرَ لَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَرِيرِ بْنِ عَبْدِ اللَّهِ وَخُزَيْمَةَ بْنِ ثَابِتٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُبَادَةَ بْنِ الصَّامِتِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَالَ الشَّافِعِيُّ لَمْ أَسْمَعْ فِي هَذَا الْبَابِ أَنَّ الْحُدُودَ تَكُونُ كَفَّارَةً لأَهْلِهَا شَيْئًا أَحْسَنَ مِنْ هَذَا الْحَدِيثِ ‏.‏ قَالَ الشَّافِعِيُّ وَأُحِبُّ لِمَنْ أَصَابَ ذَنْبًا فَسَتَرَهُ اللَّهُ عَلَيْهِ أَنْ يَسْتُرَ عَلَى نَفْسِهِ وَيَتُوبَ فِيمَا بَيْنَهُ وَبَيْنَ رَبِّهِ ‏.‏ وَكَذَلِكَ رُوِيَ عَنْ أَبِي بَكْرٍ وَعُمَرَ أَنَّهُمَا أَمَرَا رَجُلاً أَنْ يَسْتُرَ عَلَى نَفْسِهِ ‏.‏\hadithno{1439}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Ubadah bin As-Samit:"We were with the Prophet (ﷺ) [in a gathering] and he said: 'Pledge to me that you will not associate [anything as] partners with Allah, and that you will not steal nor commit adultery.' He recited to them the Ayah. (And he said:)'Whoever among you dies, then this reward is with Allah, and whoever among you does some of this and then he is punished, it is atonement for him. And whoever does some of this and Allah covers it for him, then it is up to Allah; if He wills, He will punish them, and if He wills, He will forgive him}}
\hadithdefcmd{tirmidhi}{1440}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا زَنَتْ أَمَةُ أَحَدِكُمْ فَلْيَجْلِدْهَا ثَلاَثًا بِكِتَابِ اللَّهِ فَإِنْ عَادَتْ فَلْيَبِعْهَا وَلَوْ بِحَبْلٍ مِنْ شَعَرٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي هُرَيْرَةَ وَزَيْدِ بْنِ خَالِدٍ وَشِبْلٍ عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ الأَوْسِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ رَأَوْا أَنْ يُقِيمَ الرَّجُلُ الْحَدَّ عَلَى مَمْلُوكِهِ دُونَ السُّلْطَانِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ يُرْفَعُ إِلَى السُّلْطَانِ وَلاَ يُقِيمُ الْحَدَّ هُوَ بِنَفْسِهِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1440}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) said: "If one of your slave girl commits illegal sexual intercourse, then whip her three times according to the Book of Allah, and if she does it again then sell her, even if it is for a rope made of hair}}
\hadithdefcmd{tirmidhi}{1441}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا زَائِدَةُ بْنُ قُدَامَةَ، عَنِ السُّدِّيِّ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، قَالَ خَطَبَ عَلِيٌّ فَقَالَ يَا أَيُّهَا النَّاسُ أَقِيمُوا الْحُدُودَ عَلَى أَرِقَّائِكُمْ مَنْ أَحْصَنَ مِنْهُمْ وَمَنْ لَمْ يُحْصِنْ وَإِنَّ أَمَةً لِرَسُولِ اللَّهِ صلى الله عليه وسلم زَنَتْ فَأَمَرَنِي أَنْ أَجْلِدَهَا فَإِذَا هِيَ حَدِيثَةُ عَهْدٍ بِنِفَاسٍ فَخَشِيتُ إِنْ أَنَا جَلَدْتُهَا أَنْ أَقْتُلَهَا - أَوْ قَالَ تَمُوتَ - فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ أَحْسَنْتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالسُّدِّيُّ اسْمُهُ إِسْمَاعِيلُ بْنُ عَبْدِ الرَّحْمَنِ وَهُوَ مِنَ التَّابِعِينَ قَدْ سَمِعَ مِنْ أَنَسِ بْنِ مَالِكٍ وَرَأَى حُسَيْنَ بْنَ عَلِيِّ بْنِ أَبِي طَالِبٍ رضى الله عنه ‏.‏\hadithno{1441}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu 'Abdur-Rahman As-Sulami:"Ali gave a Khutbah, and said: 'O people, establish the penalties upon your slaves, those married from them and those unmarried. A slave girl of the Prophet (ﷺ) committed illegal sexual intercourse so he ordered me to whip her. I went to her and she was just experiencing her post-natal bleeding, so I feared that if I were to whip her I would kill her' - or he said: 'She would die' - 'so I went to the Messenger of Allah (ﷺ) and I told that to him. So he said: 'You did well}}
\hadithdefcmd{tirmidhi}{1442}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ مِسْعَرٍ، عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَرَبَ الْحَدَّ بِنَعْلَيْنِ أَرْبَعِينَ ‏.‏ قَالَ مِسْعَرٌ أَظُنُّهُ فِي الْخَمْرِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ الرَّحْمَنِ بْنِ أَزْهَرَ وَأَبِي هُرَيْرَةَ وَالسَّائِبِ وَابْنِ عَبَّاسٍ وَعُقْبَةَ بْنِ الْحَارِثِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو الصِّدِّيقِ النَّاجِيُّ اسْمُهُ بَكْرُ بْنُ عَمْرٍو وَيُقَالُ بَكْرُ بْنُ قَيْسٍ ‏.‏\hadithno{1442}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:That the Messenger of Allah (ﷺ) implemented the penalty by beating forty times, with two shoes - Mis'ar (one of the narrators) said: "It think it was for wine}}
\hadithdefcmd{tirmidhi}{1443}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أُتِيَ بِرَجُلٍ قَدْ شَرِبَ الْخَمْرَ فَضَرَبَهُ بِجَرِيدَتَيْنِ نَحْوَ الأَرْبَعِينَ وَفَعَلَهُ أَبُو بَكْرٍ فَلَمَّا كَانَ عُمَرُ اسْتَشَارَ النَّاسَ فَقَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ كَأَخَفِّ الْحُدُودِ ثَمَانِينَ ‏.‏ فَأَمَرَ بِهِ عُمَرُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ حَدَّ السَّكْرَانِ ثَمَانُونَ ‏.‏\hadithno{1443}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas:That a man who had drunk wine was brought to the Prophet (ﷺ), so he beat him about forty times with two stalks of a palm tree. So Abu Bakr did similarly, and by the time 'Umar became Khalifah he sought council from the people. And 'Abdur-Rahman bin 'Awf said: 'I see that the lightest penalty is eighty lashes,' so 'Umar ordered that}}
\hadithdefcmd{tirmidhi}{1444}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ أَبِي صَالِحٍ، عَنْ مُعَاوِيَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ شَرِبَ الْخَمْرَ فَاجْلِدُوهُ فَإِنْ عَادَ فِي الرَّابِعَةِ فَاقْتُلُوهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَالشَّرِيدِ وَشُرَحْبِيلَ بْنِ أَوْسٍ وَجَرِيرٍ وَأَبِي الرَّمَدِ الْبَلَوِيِّ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مُعَاوِيَةَ هَكَذَا رَوَى الثَّوْرِيُّ أَيْضًا عَنْ عَاصِمٍ عَنْ أَبِي صَالِحٍ عَنْ مُعَاوِيَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى ابْنُ جُرَيْجٍ وَمَعْمَرٌ عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ سَمِعْتُ مُحَمَّدًا يَقُولُ حَدِيثُ أَبِي صَالِحٍ عَنْ مُعَاوِيَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا أَصَحُّ مِنْ حَدِيثِ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَإِنَّمَا كَانَ هَذَا فِي أَوَّلِ الأَمْرِ ثُمَّ نُسِخَ بَعْدُ هَكَذَا رَوَى مُحَمَّدُ بْنُ إِسْحَاقَ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ مَنْ شَرِبَ الْخَمْرَ فَاجْلِدُوهُ فَإِنْ عَادَ فِي الرَّابِعَةِ فَاقْتُلُوهُ ‏"‏ ‏.‏ قَالَ ثُمَّ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بَعْدَ ذَلِكَ بِرَجُلٍ قَدْ شَرِبَ الْخَمْرَ فِي الرَّابِعَةِ فَضَرَبَهُ وَلَمْ يَقْتُلْهُ ‏.‏ وَكَذَلِكَ رَوَى الزُّهْرِيُّ عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏ قَالَ فَرُفِعَ الْقَتْلُ وَكَانَتْ رُخْصَةً ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ لاَ نَعْلَمُ بَيْنَهُمُ اخْتِلاَفًا فِي ذَلِكَ فِي الْقَدِيمِ وَالْحَدِيثِ وَمِمَّا يُقَوِّي هَذَا مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ أَوْجُهٍ كَثِيرَةٍ أَنَّهُ قَالَ ‏"‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ إِلاَّ بِإِحْدَى ثَلاَثٍ النَّفْسُ بِالنَّفْسِ وَالثَّيِّبُ الزَّانِي وَالتَّارِكُ لِدِينِهِ ‏"‏ ‏.‏\hadithno{1444}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Mu'awiyah:That the Messenger of Allah (ﷺ) said: "Whoever drinks wine, then lash him. If he returns to it, then on the fourth time kill him}}
\hadithdefcmd{tirmidhi}{1445}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، أَخْبَرَتْهُ عَمْرَةُ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْطَعُ فِي رُبْعِ دِينَارٍ فَصَاعِدًا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ عَمْرَةَ عَنْ عَائِشَةَ مَرْفُوعًا وَرَوَاهُ بَعْضُهُمْ عَنْ عَمْرَةَ عَنْ عَائِشَةَ مَوْقُوفًا ‏.‏\hadithno{1445}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:That the Prophet (ﷺ) used to cut the hand for a fourth of a Dinar and beyond that}}
\hadithdefcmd{tirmidhi}{1446}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَطَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مِجَنٍّ قِيمَتُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَأَيْمَنَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ أَبُو بَكْرٍ الصِّدِّيقُ قَطَعَ فِي خَمْسَةِ دَرَاهِمَ ‏.‏ وَرُوِيَ عَنْ عُثْمَانَ وَعَلِيٍّ أَنَّهُمَا قَطَعَا فِي رُبْعِ دِينَارٍ ‏.‏ وَرُوِيَ عَنْ أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ أَنَّهُمَا قَالاَ تُقْطَعُ الْيَدُ فِي خَمْسَةِ دَرَاهِمَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ فُقَهَاءِ التَّابِعِينَ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ رَأَوُا الْقَطْعَ فِي رُبْعِ دِينَارٍ فَصَاعِدًا ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ مَسْعُودٍ أَنَّهُ قَالَ لاَ قَطْعَ إِلاَّ فِي دِينَارٍ أَوْ عَشَرَةِ دَرَاهِمَ ‏.‏ وَهُوَ حَدِيثٌ مُرْسَلٌ رَوَاهُ الْقَاسِمُ بْنُ عَبْدِ الرَّحْمَنِ عَنِ ابْنِ مَسْعُودٍ وَالْقَاسِمُ لَمْ يَسْمَعْ مِنِ ابْنِ مَسْعُودٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ قَالُوا لاَ قَطْعَ فِي أَقَلَّ مِنْ عَشَرَةِ دَرَاهِمَ ‏.‏ وَرُوِيَ عَنْ عَلِيٍّ أَنَّهُ قَالَ لاَ قَطْعَ فِي أَقَلَّ مِنْ عَشَرَةِ دَرَاهِمَ ‏.‏ وَلَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ ‏.‏\hadithno{1446}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:"The Messenger of Allah (ﷺ) cut the hand for a shield worth three Dirham}}
\hadithdefcmd{tirmidhi}{1447}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ الْمُقَدَّمِيُّ، حَدَّثَنَا الْحَجَّاجُ، عَنْ مَكْحُولٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُحَيْرِيزٍ، قَالَ سَأَلْتُ فَضَالَةَ بْنَ عُبَيْدٍ عَنْ تَعْلِيقِ الْيَدِ، فِي عُنُقِ السَّارِقِ أَمِنَ السُّنَّةِ هُوَ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَارِقٍ فَقُطِعَتْ يَدُهُ ثُمَّ أَمَرَ بِهَا فَعُلِّقَتْ فِي عُنُقِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عُمَرَ بْنِ عَلِيٍّ الْمُقَدَّمِيِّ عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ مُحَيْرِيزٍ هُوَ أَخُو عَبْدِ اللَّهِ بْنِ مُحَيْرِيزٍ شَامِيٌّ ‏.‏\hadithno{1447}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdur-Rahman bin Muhariz said:"I asked Fadalah bin 'Ubaid about hanging the hand around the neck of the thief: 'Is this from the Sunnah?' He said: 'A man came to the Messenger of Allah (ﷺ) with a thief so his hand was cut off, and then he ordered that it be hung around his neck}}
\hadithdefcmd{tirmidhi}{1448}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى خَائِنٍ وَلاَ مُنْتَهِبٍ وَلاَ مُخْتَلِسٍ قَطْعٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَقَدْ رَوَاهُ مُغِيرَةُ بْنُ مُسْلِمٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ ابْنِ جُرَيْجٍ ‏.‏ وَمُغِيرَةُ بْنُ مُسْلِمٍ هُوَ بَصْرِيٌّ أَخُو عَبْدِ الْعَزِيزِ الْقَسْمَلِيِّ كَذَا قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ ‏.‏\hadithno{1448}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir :That the Prophet (ﷺ) said: "There is no cutting of the hand for the traitor, or the embezzler, nor the plunderer}}
\hadithdefcmd{tirmidhi}{1449}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، أَنَّ رَافِعَ بْنَ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى بَعْضُهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ عَنْ عَمِّهِ وَاسِعِ بْنِ حَبَّانَ عَنْ رَافِعِ بْنِ خَدِيجٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ رِوَايَةِ اللَّيْثِ بْنِ سَعْدٍ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ عَنْ رَافِعِ بْنِ خَدِيجٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرُوا فِيهِ عَنْ وَاسِعِ بْنِ حَبَّانَ ‏.‏\hadithno{1449}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Rafi' bin Khadij:That he heard the Messenger of Allah (ﷺ) say: "There is no cutting of the hand for fruits or palm marrow}}
\hadithdefcmd{tirmidhi}{1450}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَيَّاشِ بْنِ عَبَّاسٍ الْمِصْرِيِّ، عَنْ شُيَيْمِ بْنِ بَيْتَانَ، عَنْ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، عَنْ بُسْرِ بْنِ أَرْطَاةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْطَعُ الأَيْدِي فِي الْغَزْوِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى غَيْرُ ابْنِ لَهِيعَةَ بِهَذَا الإِسْنَادِ نَحْوَ هَذَا ‏.‏ وَيُقَالُ بُسْرُ بْنُ أَبِي أَرْطَاةَ أَيْضًا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْهُمُ الأَوْزَاعِيُّ لاَ يَرَوْنَ أَنْ يُقَامَ الْحَدُّ فِي الْغَزْوِ بِحَضْرَةِ الْعَدُوِّ مَخَافَةَ أَنْ يَلْحَقَ مَنْ يُقَامُ عَلَيْهِ الْحَدُّ بِالْعَدُوِّ فَإِذَا خَرَجَ الإِمَامُ مِنْ أَرْضِ الْحَرْبِ وَرَجَعَ إِلَى دَارِ الإِسْلاَمِ أَقَامَ الْحَدَّ عَلَى مَنْ أَصَابَهُ ‏.‏ كَذَلِكَ قَالَ الأَوْزَاعِيُّ ‏.‏\hadithno{1450}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Busr Bin Artah:That the Prophet (ﷺ) said: "The hands are not cut in the battles}}
\hadithdefcmd{tirmidhi}{1451}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، وَأَيُّوبَ بْنِ مِسْكِينٍ، عَنْ قَتَادَةَ، عَنْ حَبِيبِ بْنِ سَالِمٍ، قَالَ رُفِعَ إِلَى النُّعْمَانِ بْنِ بَشِيرٍ رَجُلٌ وَقَعَ عَلَى جَارِيَةِ امْرَأَتِهِ فَقَالَ لأَقْضِيَنَّ فِيهَا بِقَضَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم لَئِنْ كَانَتْ أَحَلَّتْهَا لَهُ لأَجْلِدَنَّهُ مِائَةً وَإِنْ لَمْ تَكُنْ أَحَلَّتْهَا لَهُ رَجَمْتُهُ ‏.‏\hadithno{1451}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Habib bin Salim said:"A man was brought to An-Nu'man bin Bashir who had relations with the slave girl of his wife. He said: 'I give you judgement about her case according to the judgement of the Messenger of Allah (ﷺ): If she made her lawful for him, then I will lash him one hundred times, and if she did not make her lawful, then I will stone him}}
\hadithdefcmd{tirmidhi}{1452}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ، ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ النُّعْمَانِ فِي إِسْنَادِهِ اضْطِرَابٌ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدًا يَقُولُ لَمْ يَسْمَعْ قَتَادَةُ مِنْ حَبِيبِ بْنِ سَالِمٍ هَذَا الْحَدِيثَ إِنَّمَا رَوَاهُ عَنْ خَالِدِ بْنِ عُرْفُطَةَ ‏.‏ وَيُرْوَى عَنْ قَتَادَةَ أَنَّهُ قَالَ كَتَبَ بِهِ إِلَىَّ حَبِيبُ بْنُ سَالِمٍ ‏.‏ وَأَبُو بِشْرٍ لَمْ يَسْمَعْ مِنْ حَبِيبِ بْنِ سَالِمٍ هَذَا أَيْضًا إِنَّمَا رَوَاهُ عَنْ خَالِدِ بْنِ عُرْفُطَةَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الرَّجُلِ يَقَعُ عَلَى جَارِيَةِ امْرَأَتِهِ فَرُوِيَ عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عَلِيٌّ وَابْنُ عُمَرَ أَنَّ عَلَيْهِ الرَّجْمَ ‏.‏ وَقَالَ ابْنُ مَسْعُودٍ لَيْسَ عَلَيْهِ حَدٌّ وَلَكِنْ يُعَزَّرُ ‏.‏ وَذَهَبَ أَحْمَدُ وَإِسْحَاقُ إِلَى مَا رَوَى النُّعْمَانُ بْنُ بَشِيرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1452}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) from An-Nu'man bin Bashir with similar}}
\hadithdefcmd{tirmidhi}{1453}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا مُعَمَّرُ بْنُ سُلَيْمَانَ الرَّقِّيُّ، عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ، عَنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلِ بْنِ حُجْرٍ، عَنْ أَبِيهِ، قَالَ اسْتُكْرِهَتِ امْرَأَةٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَرَأَ عَنْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْحَدَّ وَأَقَامَهُ عَلَى الَّذِي أَصَابَهَا وَلَمْ يُذْكَرْ أَنَّهُ جَعَلَ لَهَا مَهْرًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَلَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدًا يَقُولُ عَبْدُ الْجَبَّارِ بْنُ وَائِلِ بْنِ حُجْرٍ لَمْ يَسْمَعْ مِنْ أَبِيهِ وَلاَ أَدْرَكَهُ يُقَالُ إِنَّهُ وُلِدَ بَعْدَ مَوْتِ أَبِيهِ بِأَشْهُرٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنْ لَيْسَ عَلَى الْمُسْتَكْرَهَةِ حَدٌّ ‏.‏\hadithno{1453}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdul-Jabbar bin Wa'il bin Hujr:That his father said: "A woman was forced to commit illegal sexual relations during the time of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) did not enforce the legal punishment upon her, but he enforced it upon the one who had done it to her." And the narrator did not mention him assigning a dowry to her}}
\hadithdefcmd{tirmidhi}{1454}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ إِسْرَائِيلَ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ الْكِنْدِيِّ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، خَرَجَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم تُرِيدُ الصَّلاَةَ فَتَلَقَّاهَا رَجُلٌ فَتَجَلَّلَهَا فَقَضَى حَاجَتَهُ مِنْهَا فَصَاحَتْ فَانْطَلَقَ وَمَرَّ عَلَيْهَا رَجُلٌ فَقَالَتْ إِنَّ ذَاكَ الرَّجُلَ فَعَلَ بِي كَذَا وَكَذَا ‏.‏ وَمَرَّتْ بِعِصَابَةٍ مِنَ الْمُهَاجِرِينَ فَقَالَتْ إِنَّ ذَاكَ الرَّجُلَ فَعَلَ بِي كَذَا وَكَذَا ‏.‏ فَانْطَلَقُوا فَأَخَذُوا الرَّجُلَ الَّذِي ظَنَّتْ أَنَّهُ وَقَعَ عَلَيْهَا وَأَتَوْهَا فَقَالَتْ نَعَمْ هُوَ هَذَا ‏.‏ فَأَتَوْا بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَلَمَّا أَمَرَ بِهِ لِيُرْجَمَ قَامَ صَاحِبُهَا الَّذِي وَقَعَ عَلَيْهَا فَقَالَ يَا رَسُولَ اللَّهِ أَنَا صَاحِبُهَا ‏.‏ فَقَالَ لَهَا ‏"‏ اذْهَبِي فَقَدْ غَفَرَ اللَّهُ لَكِ ‏"‏ ‏.‏ وَقَالَ لِلرَّجُلِ قَوْلاً حَسَنًا وَقَالَ لِلرَّجُلِ الَّذِي وَقَعَ عَلَيْهَا ‏"‏ ارْجُمُوهُ ‏"‏ ‏.‏ وَقَالَ ‏"‏ لَقَدْ تَابَ تَوْبَةً لَوْ تَابَهَا أَهْلُ الْمَدِينَةِ لَقُبِلَ مِنْهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَعَلْقَمَةُ بْنُ وَائِلِ بْنِ حُجْرٍ سَمِعَ مِنْ أَبِيهِ وَهُوَ أَكْبَرُ مِنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلٍ وَعَبْدُ الْجَبَّارِ بْنُ وَائِلٍ لَمْ يَسْمَعْ مِنْ أَبِيهِ ‏.‏\hadithno{1454}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Alqamah bin Wa'il Al-Kindi:From his father: "A women went out during the time of the Prophet (ﷺ) to go to Salat, but she was caught by a man and he had relations with her, so she screamed and he left. Then a man came across her and she said: 'That man has done this and that to me', then she came across a group of Emigrants (Muhajirin) and she said: 'That man did this and that to me.' They went to get the man she thought had relations with her, and they brought him to her. She said: 'Yes, that's him.' So they brought him to the Messenger of Allah (ﷺ), and when he ordered that he be stoned, the man who had relations with her, said: 'O Messenger of Allah, I am the one who had relations with her.' So he said to her: 'Go, for Allah has forgiven you.' Then he said some nice words to the man (who was brought). And he said to the man who had relations with her: 'Stone him.' Then he said: 'He has repented a repentance that, if the inhabitants of Al-Madinah had repented with, it would have been accepted from them}}
\hadithdefcmd{tirmidhi}{1455}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو السَّوَّاقُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَجَدْتُمُوهُ وَقَعَ عَلَى بَهِيمَةٍ فَاقْتُلُوهُ وَاقْتُلُوا الْبَهِيمَةَ ‏"‏ ‏.‏ فَقِيلَ لاِبْنِ عَبَّاسٍ مَا شَأْنُ الْبَهِيمَةِ قَالَ مَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ شَيْئًا وَلَكِنْ أُرَى رَسُولَ اللَّهِ كَرِهَ أَنْ يُؤْكَلَ مِنْ لَحْمِهَا أَوْ يُنْتَفَعَ بِهَا وَقَدْ عُمِلَ بِهَا ذَلِكَ الْعَمَلُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَمْرِو بْنِ أَبِي عَمْرٍو عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1455}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih}\hadithtrans{Narrated Ibn 'Abbas: That the Messenger of Allah (ﷺ) said: "Whomever you see having relations with an animal then kill him and kill animal." So it was said to Ibn 'Abbas: "What is the case of the animal?" He said: "I did not hear anything from the Messenger of Allah (ﷺ) about this, but I see that the Messenger of Allah (ﷺ) disliked eating its meat or using it, due to the fact that such a (heinous) thing has been done with that animal}}
\hadithdefcmd{tirmidhi}{1456}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو السَّوَّاقُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ وَجَدْتُمُوهُ يَعْمَلُ عَمَلَ قَوْمِ لُوطٍ فَاقْتُلُوا الْفَاعِلَ وَالْمَفْعُولَ بِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا يُعْرَفُ هَذَا الْحَدِيثُ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ هَذَا الْوَجْهِ وَرَوَى مُحَمَّدُ بْنُ إِسْحَاقَ هَذَا الْحَدِيثَ عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو فَقَالَ ‏"‏ مَلْعُونٌ مَنْ عَمِلَ عَمَلَ قَوْمِ لُوطٍ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ الْقَتْلَ وَذَكَرَ فِيهِ مَلْعُونٌ مَنْ أَتَى بَهِيمَةً ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَاصِمِ بْنِ عُمَرَ عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ اقْتُلُوا الْفَاعِلَ وَالْمَفْعُولَ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ فِي إِسْنَادِهِ مَقَالٌ وَلاَ نَعْرِفُ أَحَدًا رَوَاهُ عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ غَيْرَ عَاصِمِ بْنِ عُمَرَ الْعُمَرِيِّ ‏.‏ وَعَاصِمُ بْنُ عُمَرَ يُضَعَّفُ فِي الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي حَدِّ اللُّوطِيِّ فَرَأَى بَعْضُهُمْ أَنَّ عَلَيْهِ الرَّجْمَ أَحْصَنَ أَوْ لَمْ يُحْصِنْ وَهَذَا قَوْلُ مَالِكٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ فُقَهَاءِ التَّابِعِينَ مِنْهُمُ الْحَسَنُ الْبَصْرِيُّ وَإِبْرَاهِيمُ النَّخَعِيُّ وَعَطَاءُ بْنُ أَبِي رَبَاحٍ وَغَيْرُهُمْ قَالُوا حَدُّ اللُّوطِيِّ حَدُّ الزَّانِي وَهُوَ قَوْلُ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{1456}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:That the Messenger of Allah (ﷺ) said: "Whomever you find doing the actions of the people of Lut then kill the one doing it, and the one it is done to}}
\hadithdefcmd{tirmidhi}{1457}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا هَمَّامٌ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الْوَاحِدِ الْمَكِّيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَخْوَفَ مَا أَخَافُ عَلَى أُمَّتِي عَمَلُ قَوْمِ لُوطٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلِ بْنِ أَبِي طَالِبٍ عَنْ جَابِرٍ ‏.‏\hadithno{1457}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:That the Messenger of Allah (ﷺ) said: "What I fear most from my Ummah is the behavior of the people of Lut}}
\hadithdefcmd{tirmidhi}{1458}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، أَنَّ عَلِيًّا، حَرَّقَ قَوْمًا ارْتَدُّوا عَنِ الإِسْلاَمِ، فَبَلَغَ ذَلِكَ ابْنَ عَبَّاسٍ فَقَالَ لَوْ كُنْتُ أَنَا لَقَتَلْتُهُمْ، لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏ وَلَمْ أَكُنْ لأُحَرِّقَهُمْ لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُعَذِّبُوا بِعَذَابِ اللَّهِ ‏"‏ ‏.‏ فَبَلَغَ ذَلِكَ عَلِيًّا فَقَالَ صَدَقَ ابْنُ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ فِي الْمُرْتَدِّ ‏.‏ وَاخْتَلَفُوا فِي الْمَرْأَةِ إِذَا ارْتَدَّتْ عَنِ الإِسْلاَمِ فَقَالَتْ طَائِفَةٌ مِنْ أَهْلِ الْعِلْمِ تُقْتَلُ وَهُوَ قَوْلُ الأَوْزَاعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَتْ طَائِفَةٌ مِنْهُمْ تُحْبَسُ وَلاَ تُقْتَلُ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَغَيْرِهِ مِنْ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{1458}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Ikrimah:That 'Ali burnt some people who apostasized from Islam. This news reached Ibn 'Abbas, so he said: "If it were me I would have killed them according to the statement of Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said: 'Whoever changes his religion then kill him.' And I would not have burned them because the Messenger of Allah (ﷺ) said: 'Do not punish with the punishment of Allah.' So this reached 'Ali, and he said: "Ibn 'Abbas has told the truth}}
\hadithdefcmd{tirmidhi}{1459}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَأَبُو السَّائِبِ، سَلْمُ بْنُ جُنَادَةَ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَمَلَ عَلَيْنَا السِّلاَحَ فَلَيْسَ مِنَّا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ الزُّبَيْرِ وَأَبِي هُرَيْرَةَ وَسَلَمَةَ بْنِ الأَكْوَعِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي مُوسَى حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1459}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Musa:That the Prophet (ﷺ) said: "Whoever carries weapons against us, he is not from us}}
\hadithdefcmd{tirmidhi}{1460}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنِ الْحَسَنِ، عَنْ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَدُّ السَّاحِرِ ضَرْبَةٌ بِالسَّيْفِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَإِسْمَاعِيلُ بْنُ مُسْلِمٍ الْمَكِّيُّ يُضَعَّفُ فِي الْحَدِيثِ وَإِسْمَاعِيلُ بْنُ مُسْلِمٍ الْعَبْدِيُّ الْبَصْرِيُّ قَالَ وَكِيعٌ هُوَ ثِقَةٌ ‏.‏ وَيُرْوَى عَنِ الْحَسَنِ أَيْضًا وَالصَّحِيحُ عَنْ جُنْدَبٍ مَوْقُوفٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ ‏.‏ وَقَالَ الشَّافِعِيُّ إِنَّمَا يُقْتَلُ السَّاحِرُ إِذَا كَانَ يَعْمَلُ فِي سِحْرِهِ مَا يَبْلُغُ بِهِ الْكُفْرَ فَإِذَا عَمِلَ عَمَلاً دُونَ الْكُفْرِ فَلَمْ نَرَ عَلَيْهِ قَتْلاً ‏.‏\hadithno{1460}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jundab:That he heard the Messenger of Allah (ﷺ) saying: "The punishment of the Sahir is a strike of the sword}}
\hadithdefcmd{tirmidhi}{1461}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو السَّوَّاقُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ صَالِحِ بْنِ مُحَمَّدِ بْنِ زَائِدَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ وَجَدْتُمُوهُ غَلَّ فِي سَبِيلِ اللَّهِ فَاحْرِقُوا مَتَاعَهُ ‏"‏ ‏.‏ قَالَ صَالِحٌ فَدَخَلْتُ عَلَى مَسْلَمَةَ وَمَعَهُ سَالِمُ بْنُ عَبْدِ اللَّهِ فَوَجَدَ رَجُلاً قَدْ غَلَّ فَحَدَّثَ سَالِمٌ بِهَذَا الْحَدِيثِ فَأَمَرَ بِهِ فَأُحْرِقَ مَتَاعُهُ فَوُجِدَ فِي مَتَاعِهِ مُصْحَفٌ فَقَالَ سَالِمٌ بِعْ هَذَا وَتَصَدَّقْ بِثَمَنِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا الْحَدِيثُ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ الأَوْزَاعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ إِنَّمَا رَوَى هَذَا صَالِحُ بْنُ مُحَمَّدِ بْنِ زَائِدَةَ وَهُوَ أَبُو وَاقِدٍ اللَّيْثِيُّ وَهُوَ مُنْكَرُ الْحَدِيثِ قَالَ مُحَمَّدٌ وَقَدْ رُوِيَ فِي غَيْرِ حَدِيثٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْغَالِّ فَلَمْ يَأْمُرْ فِيهِ بِحَرْقِ مَتَاعِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{1461}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar:That the Messenger of Allah (ﷺ) said: "Whomever you find stealing from the spoils of war while in the path of Allah, then burn his belongings." Salih (one of the narrators) said: "I entered upon Maslamah and with him was Salim bin 'Abdullah. There was a man there who had stolen from the spoils of war, so Salim narrated this Hadith. So he ordered accordingly, and his belongings were burnt. There was a Mushaf in his belongings, so Salim said: 'Sell this and give its proceeds as charity}}
\hadithdefcmd{tirmidhi}{1462}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ إِبْرَاهِيمَ بْنِ إِسْمَاعِيلَ بْنِ أَبِي حَبِيبَةَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الرَّجُلُ لِلرَّجُلِ يَا يَهُودِيُّ فَاضْرِبُوهُ عِشْرِينَ وَإِذَا قَالَ يَا مُخَنَّثُ فَاضْرِبُوهُ عِشْرِينَ وَمَنْ وَقَعَ عَلَى ذَاتِ مَحْرَمٍ فَاقْتُلُوهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَإِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَصْحَابِنَا قَالُوا مَنْ أَتَى ذَاتَ مَحْرَمٍ وَهُوَ يَعْلَمُ فَعَلَيْهِ الْقَتْلُ ‏.‏ وَقَالَ أَحْمَدُ مَنْ تَزَوَّجَ أُمَّهُ قُتِلَ ‏.‏ وَقَالَ إِسْحَاقُ مَنْ وَقَعَ عَلَى ذَاتِ مَحْرَمٍ قُتِلَ ‏.‏ - وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ رَوَاهُ الْبَرَاءُ بْنُ عَازِبٍ وَقُرَّةُ بْنُ إِيَاسٍ الْمُزَنِيُّ أَنَّ رَجُلاً تَزَوَّجَ امْرَأَةَ أَبِيهِ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِقَتْلِهِ ‏.‏\hadithno{1462}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:That the Prophet (ﷺ) said: "If a man says to another man: 'O you Jew' then beat him twenty times. If he says: 'O you effeminate' then beat him twenty times. And whoever has relations with someone that is a Mahram then kill him}}
\hadithdefcmd{tirmidhi}{1463}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ بْنِ نِيَارٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُجْلَدُ فَوْقَ عَشْرِ جَلَدَاتٍ إِلاَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ بُكَيْرِ بْنِ الأَشَجِّ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي التَّعْزِيرِ وَأَحْسَنُ شَيْءٍ رُوِيَ فِي التَّعْزِيرِ هَذَا الْحَدِيثُ ‏.‏ قَالَ وَقَدْ رَوَى هَذَا الْحَدِيثَ ابْنُ لَهِيعَةَ عَنْ بُكَيْرٍ فَأَخْطَأَ فِيهِ وَقَالَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ خَطَأٌ وَالصَّحِيحُ حَدِيثُ اللَّيْثِ بْنِ سَعْدٍ إِنَّمَا هُوَ عَبْدُ الرَّحْمَنِ بْنُ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِي بُرْدَةَ بْنِ نِيَارٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1463}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Burdah bun Niyar:That the Messenger of Allah (ﷺ) said: "No one is to be lashed more than ten lashes except for a legal punishment among Allah's punishments}}
